==> reposTools_1.4.3.tar.gz: reposTools/man/repdatadesc-class.Rd <==
\name{repdatadesc-class}
\docType{class}
\alias{repdatadesc-class}
\alias{repdatadesc}
\alias{depends,repdatadesc-method}
\alias{keywords,repdatadesc-method}
\alias{repdatadesc,repdatadesc-method}
\alias{show,repdatadesc-method}
\alias{suggests,repdatadesc-method}
\alias{summary,repdatadesc-method}
\alias{uses,repdatadesc-method}
\title{A class to represent a repository data frame}
\description{Provides a structure and representation for repository
  dataframe objects}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("repdatadesc", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{repdatadesc}:}{Object of class \code{"data.frame"} A
      repository data frame}
  }
}

\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "repdatadesc")}: A verbose
      output of the contents}
    \item{summary}{\code{signature(object = "repdatadesc")}: A brief output
    of the contents}
    \item{repdatadesc}{\code{signature(object = "repdatadesc")}: The
      dataframe itself}
    \item{depends}{\code{signature(object = "repdatadesc")}: Returns the
      \code{depends} information for a given package}
    \item{uses}{\code{signature(object = "repdatadesc")}: Returns the
      \code{uses} information for a given package}
    \item{suggests}{\code{signature(object = "repdatadesc")}: Returns
      the \code{suggests} information for a given package}
    \item{keywords}{\code{signature(object = "repdatadesc")}: Returns
      keywords for a given package.}
  }
}
\author{Jeff Gentry}
\seealso{\code{\link{ReposEntry-class}},\code{\link{replisting-class}}}
\examples{
data(sampleRepos)
a <- new("repdatadesc",repdatadesc=reposDF)
a
}
\keyword{classes}

==> reposTools_1.10.0.tar.gz: reposTools/man/repdatadesc-class.Rd <==
\name{repdatadesc-class}
\docType{class}
\alias{repdatadesc-class}
\alias{repdatadesc}
\alias{depends,repdatadesc-method}
\alias{keywords,repdatadesc-method}
\alias{repdatadesc,repdatadesc-method}
\alias{show,repdatadesc-method}
\alias{suggests,repdatadesc-method}
\alias{summary,repdatadesc-method}
\alias{imports,repdatadesc-method}
\title{A class to represent a repository data frame}
\description{Provides a structure and representation for repository
  dataframe objects}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("repdatadesc", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{repdatadesc}:}{Object of class \code{"data.frame"} A
      repository data frame}
  }
}

\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "repdatadesc")}: A verbose
      output of the contents}
    \item{summary}{\code{signature(object = "repdatadesc")}: A brief output
    of the contents}
    \item{repdatadesc}{\code{signature(object = "repdatadesc")}: The
      dataframe itself}
    \item{depends}{\code{signature(object = "repdatadesc")}: Returns the
      \code{depends} information for a given package}
    \item{imports}{\code{signature(object = "repdatadesc")}: Returns the
      \code{imports} information for a given package}
    \item{suggests}{\code{signature(object = "repdatadesc")}: Returns
      the \code{suggests} information for a given package}
    \item{keywords}{\code{signature(object = "repdatadesc")}: Returns
      keywords for a given package.}
  }
}
\author{Jeff Gentry}
\seealso{\code{\link{ReposEntry-class}},\code{\link{replisting-class}}}
\examples{
data(sampleRepos)
a <- new("repdatadesc",repdatadesc=reposDF)
a
}
\keyword{classes}
